@@ -14,14 +14,14 @@
 #' @param constr_dy_x_meas input character vector detailing which measurement model parameters to constrain across dyad members for latent X.
 #' Default is c("loadings", "intercepts", "residuals"),
 #' but user can specify any combination of "loadings", "intercepts", and "residuals",
-#' #or "none" to specify an otherwise unconstrained dyadic configural invariance model
+#' or "none" to specify an otherwise unconstrained dyadic configural invariance model
 #' @param constr_dy_x_struct input character vector detailing which structural model parameters to constrain across dyad members for latent X.
 #' Default is c("variances", "means"),
 #' but user can specify any combination of "variances" and "means", or "none".
 #' @param constr_dy_y_meas input character vector detailing which measurement model parameters to constrain across dyad members for latent X.
 #' Default is c("loadings", "intercepts", "residuals"),
 #' but user can specify any combination of "loadings", "intercepts", and "residuals",
-#' #or "none" to specify an otherwise unconstrained dyadic configural invariance model
+#' or "none" to specify an otherwise unconstrained dyadic configural invariance model
 #' @param constr_dy_y_struct input character vector detailing which structural model parameters to constrain across dyad members for latent X.
 #' Default is c("variances", "means"),
 #' but user can specify any combination of "variances" and "means", or "none".
@@ -42,7 +42,7 @@
 #' when the recommended level of invariance is not also specified. If user supplies dvn
 #' with containing X or Y variables, they are alerted to respecify the dvn object.
 #' @seealso \code{\link{scrapeVarCross}} which this function relies on
-#' @family script-writing functions
+#' @family bi-construct script-writing functions
 #' @export
 #' @examples
 #' dvn <- scrapeVarCross(dat = commitmentQ, x_order = "spi", x_stem = "sat.g", x_delim1 = ".",
@@ -64,6 +64,8 @@ scriptCFM  <- function(dvn, scaleset = "FF",
                      writeTo = NULL,
                      fileName = NULL){
 
+  warning("scriptCFM has some specification problems under certain patterns of constraints and is likely to see a major update in the near future; please consider delaying its use (this message will be removed when the update is complete)")
+
   #stop if model is provided
   if (lifecycle::is_present(model)) {
     lifecycle::deprecate_stop(
@@ -141,10 +143,13 @@ scriptCFM  <- function(dvn, scaleset = "FF",
 
   #Common Fate Loadings
   if(scaleset == "FF"){
-    hierloads <- cfloads(dvn, lvxname = lvxname, lvyname = lvyname, type = "equated")
+    hierloadsx <- cfloads(dvn, lvname = lvxname, type = "equated_x")
+    hierloadsy <- cfloads(dvn, lvname = lvyname, type = "equated_y")
 
   }else if(scaleset == "MV"){
-    hierloads <- cfloads(dvn, lvxname = lvxname, lvyname = lvyname, type = "fixed")
+    hierloadsx <- cfloads(dvn, lvname = lvxname, type = "fixed_x")
+    hierloadsy <- cfloads(dvn, lvname = lvyname, type = "fixed_y")
+
   }
 
   #intercepts for X
@@ -351,10 +356,10 @@ scriptCFM  <- function(dvn, scaleset = "FF",
   }
 
   #write script
-  script <- sprintf("#Measurement Model\n\n#Loadings\n%s\n%s\n\n%s\n%s\n\n%s\n\n#Intercepts\n%s\n\n%s\n\n%s\n\n%s\n\n#Residual Variances\n%s\n\n%s\n\n%s\n\n%s\n\n#Residual Covariances\n%s\n\n%s\n\n#Structural Model\n\n#Latent (Co)Variances\n%s\n%s\n%s\n\n%s\n%s\n%s\n\n%s\n%s\n\n#Latent Means\n%s\n%s\n%s\n\n%s\n%s\n%s\n\n#Latent Dyadic Effect\n%s",
+  script <- sprintf("#Measurement Model\n\n#Loadings\n%s\n%s\n\n%s\n%s\n\n%s\n%s\n\n#Intercepts\n%s\n\n%s\n\n%s\n\n%s\n\n#Residual Variances\n%s\n\n%s\n\n%s\n\n%s\n\n#Residual Covariances\n%s\n\n%s\n\n#Structural Model\n\n#Latent (Co)Variances\n%s\n%s\n%s\n\n%s\n%s\n%s\n\n%s\n%s\n\n#Latent Means\n%s\n%s\n%s\n\n%s\n%s\n%s\n\n#Latent Dyadic Effect\n%s",
                     xloads1, xloads2,
                     yloads1, yloads2,
-                    hierloads,
+                    hierloadsx,hierloadsy,
                     xints1, xints2,
                     yints1, yints2,
                     xres1, xres2,
